@@ -42,31 +42,34 @@ G_BEGIN_DECLS
 #define GTK_IS_BUTTON_BOX(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_BUTTON_BOX))
 #define GTK_IS_BUTTON_BOX_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_BUTTON_BOX))
 #define GTK_BUTTON_BOX_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_BUTTON_BOX, GtkButtonBoxClass))
-  
 
-#define GTK_BUTTONBOX_DEFAULT -1
- 
-typedef struct _GtkButtonBox       GtkButtonBox;
-typedef struct _GtkButtonBoxClass  GtkButtonBoxClass;
+
+typedef struct _GtkButtonBox              GtkButtonBox;
+typedef struct _GtkButtonBoxPrivate       GtkButtonBoxPrivate;
+typedef struct _GtkButtonBoxClass         GtkButtonBoxClass;
 
 struct _GtkButtonBox
 {
   GtkBox box;
-  gint GSEAL (child_min_width);
-  gint GSEAL (child_min_height);
-  gint GSEAL (child_ipad_x);
-  gint GSEAL (child_ipad_y);
-  GtkButtonBoxStyle GSEAL (layout_style);
+
+  /*< private >*/
+  GtkButtonBoxPrivate *priv;
 };
 
 struct _GtkButtonBoxClass
 {
   GtkBoxClass parent_class;
+
+  /* Padding for future expansion */
+  void (*_gtk_reserved1) (void);
+  void (*_gtk_reserved2) (void);
+  void (*_gtk_reserved3) (void);
+  void (*_gtk_reserved4) (void);
 };
 
 
-GType gtk_button_box_get_type (void) G_GNUC_CONST;
-
+GType             gtk_button_box_get_type            (void) G_GNUC_CONST;
+GtkWidget       * gtk_button_box_new                 (GtkOrientation     orientation);
 GtkButtonBoxStyle gtk_button_box_get_layout          (GtkButtonBox      *widget);
 void              gtk_button_box_set_layout          (GtkButtonBox      *widget,
 						      GtkButtonBoxStyle  layout_style);
@@ -76,12 +79,6 @@ void              gtk_button_box_set_child_secondary (GtkButtonBox      *widget,
 						      GtkWidget         *child,
 						      gboolean           is_secondary);
 
-/* Internal method - do not use. */
-void _gtk_button_box_child_requisition (GtkWidget *widget,
-					int       *nvis_children,
-					int       *nvis_secondaries,
-					int       *width,
-					int       *height);
 G_END_DECLS
 
 #endif /* __GTK_BUTTON_BOX_H__ */
