@@ -27,6 +27,7 @@
 #include <gtk/gtkcontainer.h>
 #include <gtk/gtktreemodel.h>
 #include <gtk/gtkcellrenderer.h>
+#include <gtk/gtkcellarea.h>
 #include <gtk/gtkselection.h>
 #include <gtk/gtktooltip.h>
 
@@ -81,7 +82,7 @@ struct _GtkIconView
 {
   GtkContainer parent;
 
-  /* <private> */
+  /*< private >*/
   GtkIconViewPrivate *priv;
 };
 
@@ -89,10 +90,6 @@ struct _GtkIconViewClass
 {
   GtkContainerClass parent_class;
 
-  void    (* set_scroll_adjustments) (GtkIconView      *icon_view,
-				      GtkAdjustment    *hadjustment,
-				      GtkAdjustment    *vadjustment);
-  
   void    (* item_activated)         (GtkIconView      *icon_view,
 				      GtkTreePath      *path);
   void    (* selection_changed)      (GtkIconView      *icon_view);
@@ -106,10 +103,17 @@ struct _GtkIconViewClass
 				      GtkMovementStep   step,
 				      gint              count);
   gboolean (* activate_cursor_item)  (GtkIconView      *icon_view);
+
+  /* Padding for future expansion */
+  void (*_gtk_reserved1) (void);
+  void (*_gtk_reserved2) (void);
+  void (*_gtk_reserved3) (void);
+  void (*_gtk_reserved4) (void);
 };
 
 GType          gtk_icon_view_get_type          (void) G_GNUC_CONST;
 GtkWidget *    gtk_icon_view_new               (void);
+GtkWidget *    gtk_icon_view_new_with_area     (GtkCellArea    *area);
 GtkWidget *    gtk_icon_view_new_with_model    (GtkTreeModel   *model);
 
 void           gtk_icon_view_set_model         (GtkIconView    *icon_view,
@@ -125,9 +129,9 @@ void           gtk_icon_view_set_pixbuf_column (GtkIconView    *icon_view,
 					        gint            column);
 gint           gtk_icon_view_get_pixbuf_column (GtkIconView    *icon_view);
 
-void           gtk_icon_view_set_orientation   (GtkIconView    *icon_view,
-	   			                GtkOrientation  orientation);
-GtkOrientation gtk_icon_view_get_orientation   (GtkIconView    *icon_view);
+void           gtk_icon_view_set_item_orientation (GtkIconView    *icon_view,
+                                                   GtkOrientation  orientation);
+GtkOrientation gtk_icon_view_get_item_orientation (GtkIconView    *icon_view);
 void           gtk_icon_view_set_columns       (GtkIconView    *icon_view,
 		 			        gint            columns);
 gint           gtk_icon_view_get_columns       (GtkIconView    *icon_view);
@@ -150,7 +154,6 @@ void           gtk_icon_view_set_item_padding  (GtkIconView    *icon_view,
 					        gint            item_padding);
 gint           gtk_icon_view_get_item_padding  (GtkIconView    *icon_view);
 
-
 GtkTreePath *  gtk_icon_view_get_path_at_pos   (GtkIconView     *icon_view,
 						gint             x,
 						gint             y);
@@ -226,7 +229,7 @@ gboolean               gtk_icon_view_get_dest_item_at_pos     (GtkIconView
 							       gint                      drag_y,
 							       GtkTreePath             **path,
 							       GtkIconViewDropPosition  *pos);
-GdkPixmap             *gtk_icon_view_create_drag_icon         (GtkIconView              *icon_view,
+cairo_surface_t       *gtk_icon_view_create_drag_icon         (GtkIconView              *icon_view,
 							       GtkTreePath              *path);
 
 void    gtk_icon_view_convert_widget_to_bin_window_coords     (GtkIconView *icon_view,
